summaryrefslogtreecommitdiff
path: root/gr-qtgui/apps
diff options
context:
space:
mode:
Diffstat (limited to 'gr-qtgui/apps')
-rwxr-xr-xgr-qtgui/apps/gr_constellation_plot5
-rwxr-xr-xgr-qtgui/apps/gr_psd_plot_c3
-rwxr-xr-xgr-qtgui/apps/gr_psd_plot_f3
-rwxr-xr-xgr-qtgui/apps/gr_spectrogram_plot_c3
-rwxr-xr-xgr-qtgui/apps/gr_spectrogram_plot_f3
-rwxr-xr-xgr-qtgui/apps/gr_time_plot_c3
-rwxr-xr-xgr-qtgui/apps/gr_time_plot_f3
-rwxr-xr-xgr-qtgui/apps/gr_time_raster_b3
-rwxr-xr-xgr-qtgui/apps/gr_time_raster_f3
-rw-r--r--gr-qtgui/apps/plot_base.py10
-rw-r--r--gr-qtgui/apps/plot_psd_base.py2
-rw-r--r--gr-qtgui/apps/plot_spectrogram_base.py2
-rw-r--r--gr-qtgui/apps/plot_time_base.py2
-rw-r--r--gr-qtgui/apps/plot_time_raster_base.py2
-rwxr-xr-xgr-qtgui/apps/qt_digital.py2
-rwxr-xr-xgr-qtgui/apps/uhd_display.py2
16 files changed, 31 insertions, 20 deletions
diff --git a/gr-qtgui/apps/gr_constellation_plot b/gr-qtgui/apps/gr_constellation_plot
index 0687443218..559b643c53 100755
--- a/gr-qtgui/apps/gr_constellation_plot
+++ b/gr-qtgui/apps/gr_constellation_plot
@@ -21,6 +21,7 @@
#
from gnuradio import gr
+from gnuradio import blocks
from gnuradio.eng_option import eng_option
from optparse import OptionParser
import os, sys
@@ -67,7 +68,7 @@ class my_top_block(gr.top_block):
self.qapp = QtGui.QApplication(sys.argv)
- self.skip = gr.skiphead(gr.sizeof_gr_complex, self._start)
+ self.skip = blocks.skiphead(gr.sizeof_gr_complex, self._start)
self.gui_snk = qtgui.const_sink_c(self._nsamps,
"GNU Radio Constellation Plot",
self._nsigs)
@@ -77,7 +78,7 @@ class my_top_block(gr.top_block):
self._data_max = -sys.maxint - 1
for f in filelist:
data,_min,_max = read_samples_c(f, self._start, self._nsamps)
- self.srcs.append(gr.vector_source_c(data))
+ self.srcs.append(blocks.vector_source_c(data))
if(_min < self._data_min):
self._data_min = _min
diff --git a/gr-qtgui/apps/gr_psd_plot_c b/gr-qtgui/apps/gr_psd_plot_c
index f2789ef34b..6ade908bd4 100755
--- a/gr-qtgui/apps/gr_psd_plot_c
+++ b/gr-qtgui/apps/gr_psd_plot_c
@@ -21,6 +21,7 @@
#
from gnuradio import gr
+from gnuradio import blocks
from gnuradio import filter
import scipy
@@ -46,7 +47,7 @@ class psd_plot_c(plot_base.plot_base):
self.read_samples = plot_base.read_samples_c
self.dsize = gr.sizeof_gr_complex
- self.src_type = gr.vector_source_c
+ self.src_type = blocks.vector_source_c
self.gui_snk = qtgui.freq_sink_c(self._psd_size, filter.firdes.WIN_BLACKMAN_hARRIS,
self._center_freq, self._samp_rate,
"GNU Radio PSD Plot", self._nsigs)
diff --git a/gr-qtgui/apps/gr_psd_plot_f b/gr-qtgui/apps/gr_psd_plot_f
index c6b70baf27..792b04290b 100755
--- a/gr-qtgui/apps/gr_psd_plot_f
+++ b/gr-qtgui/apps/gr_psd_plot_f
@@ -21,6 +21,7 @@
#
from gnuradio import gr
+from gnuradio import blocks
from gnuradio import filter
import scipy
@@ -46,7 +47,7 @@ class psd_plot_f(plot_base.plot_base):
self.read_samples = plot_base.read_samples_f
self.dsize = gr.sizeof_float
- self.src_type = gr.vector_source_f
+ self.src_type = blocks.vector_source_f
self.gui_snk = qtgui.freq_sink_f(self._psd_size, filter.firdes.WIN_BLACKMAN_hARRIS,
self._center_freq, self._samp_rate,
"GNU Radio PSD Plot", self._nsigs)
diff --git a/gr-qtgui/apps/gr_spectrogram_plot_c b/gr-qtgui/apps/gr_spectrogram_plot_c
index 059f65cd99..bb4fad1b7a 100755
--- a/gr-qtgui/apps/gr_spectrogram_plot_c
+++ b/gr-qtgui/apps/gr_spectrogram_plot_c
@@ -21,6 +21,7 @@
#
from gnuradio import gr
+from gnuradio import blocks
from gnuradio import filter
import scipy
@@ -46,7 +47,7 @@ class spectrogram_plot_c(plot_base.plot_base):
self.read_samples = plot_base.read_samples_c
self.dsize = gr.sizeof_gr_complex
- self.src_type = gr.vector_source_c
+ self.src_type = blocks.vector_source_c
self.gui_snk = qtgui.waterfall_sink_c(self._psd_size, filter.firdes.WIN_BLACKMAN_hARRIS,
self._center_freq, self._samp_rate,
"GNU Radio Spectrogram Plot", self._nsigs)
diff --git a/gr-qtgui/apps/gr_spectrogram_plot_f b/gr-qtgui/apps/gr_spectrogram_plot_f
index be9c981532..dcb0305bf5 100755
--- a/gr-qtgui/apps/gr_spectrogram_plot_f
+++ b/gr-qtgui/apps/gr_spectrogram_plot_f
@@ -21,6 +21,7 @@
#
from gnuradio import gr
+from gnuradio import blocks
from gnuradio import filter
import scipy
@@ -46,7 +47,7 @@ class spectrogram_plot_f(plot_base.plot_base):
self.read_samples = plot_base.read_samples_f
self.dsize = gr.sizeof_float
- self.src_type = gr.vector_source_f
+ self.src_type = blocks.vector_source_f
self.gui_snk = qtgui.waterfall_sink_f(self._psd_size, filter.firdes.WIN_BLACKMAN_hARRIS,
self._center_freq, self._samp_rate,
"GNU Radio Spectrogram Plot", self._nsigs)
diff --git a/gr-qtgui/apps/gr_time_plot_c b/gr-qtgui/apps/gr_time_plot_c
index a7c39a24b9..174b3ee1ed 100755
--- a/gr-qtgui/apps/gr_time_plot_c
+++ b/gr-qtgui/apps/gr_time_plot_c
@@ -21,6 +21,7 @@
#
from gnuradio import gr
+from gnuradio import blocks
import scipy
try:
@@ -45,7 +46,7 @@ class plot_time_c(plot_base.plot_base):
auto_scale)
self.read_samples = plot_base.read_samples_c
self.dsize = gr.sizeof_gr_complex
- self.src_type = gr.vector_source_c
+ self.src_type = blocks.vector_source_c
self.gui_snk = qtgui.time_sink_c(self._nsamps, self._samp_rate,
"GNU Radio Time Plot", self._nsigs)
self._nsigs *= 2 # complex plots have real/imag
diff --git a/gr-qtgui/apps/gr_time_plot_f b/gr-qtgui/apps/gr_time_plot_f
index 9b29709b10..9140b61220 100755
--- a/gr-qtgui/apps/gr_time_plot_f
+++ b/gr-qtgui/apps/gr_time_plot_f
@@ -21,6 +21,7 @@
#
from gnuradio import gr
+from gnuradio import blocks
import scipy
try:
@@ -45,7 +46,7 @@ class plot_time_f(plot_base.plot_base):
auto_scale)
self.read_samples = plot_base.read_samples_f
self.dsize = gr.sizeof_float
- self.src_type = gr.vector_source_f
+ self.src_type = blocks.vector_source_f
self.gui_snk = qtgui.time_sink_f(self._nsamps, self._samp_rate,
"GNU Radio Time Plot", self._nsigs)
self.setup()
diff --git a/gr-qtgui/apps/gr_time_raster_b b/gr-qtgui/apps/gr_time_raster_b
index a326a126c4..3e81c317d6 100755
--- a/gr-qtgui/apps/gr_time_raster_b
+++ b/gr-qtgui/apps/gr_time_raster_b
@@ -21,6 +21,7 @@
#
from gnuradio import gr
+from gnuradio import blocks
import scipy
try:
@@ -48,7 +49,7 @@ class plot_time_raster_b(plot_base.plot_base):
self._ncols = ncols
self.read_samples = plot_base.read_samples_b
self.dsize = gr.sizeof_char
- self.src_type = gr.vector_source_b
+ self.src_type = blocks.vector_source_b
self.gui_snk = qtgui.time_raster_sink_b(self._samp_rate, self._nrows, self._ncols,
[], [], "GNU Radio Time Plot", self._nsigs)
self.setup()
diff --git a/gr-qtgui/apps/gr_time_raster_f b/gr-qtgui/apps/gr_time_raster_f
index a6cb897c0b..6b5e5c20e9 100755
--- a/gr-qtgui/apps/gr_time_raster_f
+++ b/gr-qtgui/apps/gr_time_raster_f
@@ -21,6 +21,7 @@
#
from gnuradio import gr
+from gnuradio import blocks
import scipy
try:
@@ -48,7 +49,7 @@ class plot_time_raster_f(plot_base.plot_base):
self._ncols = ncols
self.read_samples = plot_base.read_samples_f
self.dsize = gr.sizeof_float
- self.src_type = gr.vector_source_f
+ self.src_type = blocks.vector_source_f
self.gui_snk = qtgui.time_raster_sink_f(self._samp_rate, self._nrows, self._ncols,
[], [], "GNU Radio Time Plot", self._nsigs)
self.setup()
diff --git a/gr-qtgui/apps/plot_psd_base.py b/gr-qtgui/apps/plot_psd_base.py
index a4a6cb871a..bb1567e014 100644
--- a/gr-qtgui/apps/plot_psd_base.py
+++ b/gr-qtgui/apps/plot_psd_base.py
@@ -72,7 +72,7 @@ class plot_base(gr.top_block):
self.qapp = QtGui.QApplication(sys.argv)
def setup(self):
- self.skip = gr.skiphead(self.dsize, self._start)
+ self.skip = blocks.skiphead(self.dsize, self._start)
n = 0
self.srcs = list()
diff --git a/gr-qtgui/apps/plot_spectrogram_base.py b/gr-qtgui/apps/plot_spectrogram_base.py
index adfbfd032f..a3fdf65117 100644
--- a/gr-qtgui/apps/plot_spectrogram_base.py
+++ b/gr-qtgui/apps/plot_spectrogram_base.py
@@ -72,7 +72,7 @@ class plot_base(gr.top_block):
self.qapp = QtGui.QApplication(sys.argv)
def setup(self):
- self.skip = gr.skiphead(self.dsize, self._start)
+ self.skip = blocks.skiphead(self.dsize, self._start)
n = 0
self.srcs = list()
diff --git a/gr-qtgui/apps/plot_time_base.py b/gr-qtgui/apps/plot_time_base.py
index c80bace1b6..942500c627 100644
--- a/gr-qtgui/apps/plot_time_base.py
+++ b/gr-qtgui/apps/plot_time_base.py
@@ -71,7 +71,7 @@ class plot_base(gr.top_block):
self.qapp = QtGui.QApplication(sys.argv)
def setup(self):
- self.skip = gr.skiphead(self.dsize, self._start)
+ self.skip = blocks.skiphead(self.dsize, self._start)
n = 0
self.srcs = list()
diff --git a/gr-qtgui/apps/plot_time_raster_base.py b/gr-qtgui/apps/plot_time_raster_base.py
index ff3cc2869d..2fc498ba28 100644
--- a/gr-qtgui/apps/plot_time_raster_base.py
+++ b/gr-qtgui/apps/plot_time_raster_base.py
@@ -71,7 +71,7 @@ class plot_base(gr.top_block):
self.qapp = QtGui.QApplication(sys.argv)
def setup(self):
- self.skip = gr.skiphead(self.dsize, self._start)
+ self.skip = blocks.skiphead(self.dsize, self._start)
n = 0
self.srcs = list()
diff --git a/gr-qtgui/apps/qt_digital.py b/gr-qtgui/apps/qt_digital.py
index 445d6d4fc1..fef4f448b4 100755
--- a/gr-qtgui/apps/qt_digital.py
+++ b/gr-qtgui/apps/qt_digital.py
@@ -182,7 +182,7 @@ class my_top_block(gr.top_block):
fftsize = 2048
self.data = scipy.random.randint(0, 255, 1000)
- self.src = gr.vector_source_b(self.data.tolist(), True)
+ self.src = blocks.vector_source_b(self.data.tolist(), True)
self.mod = digital.dqpsk_mod(self.gray_code,
samples_per_symbol=self.sps,
excess_bw=self.excess_bw,
diff --git a/gr-qtgui/apps/uhd_display.py b/gr-qtgui/apps/uhd_display.py
index 81950b99aa..0e0c8a177d 100755
--- a/gr-qtgui/apps/uhd_display.py
+++ b/gr-qtgui/apps/uhd_display.py
@@ -235,7 +235,7 @@ class my_top_block(gr.top_block):
self.lock()
# Add file sink to save data
- self.file_sink = gr.file_sink(gr.sizeof_gr_complex, name)
+ self.file_sink = blocks.file_sink(gr.sizeof_gr_complex, name)
self.connect(self.amp, self.file_sink)
self.unlock()
diff --git a/gr-qtgui/apps/plot_base.py b/gr-qtgui/apps/plot_base.py
index 52c888cff3..eaab7599c7 100644
--- a/gr-qtgui/apps/plot_base.py
+++ b/gr-qtgui/apps/plot_base.py
@@ -25,6 +25,8 @@ from gnuradio.eng_option import eng_option
from optparse import OptionParser
import os, sys
+os.environ['GR_CONF_CONTROLPORT_ON'] = 'False'
+
try:
from gnuradio import qtgui
from PyQt4 import QtGui, QtCore
@@ -91,7 +93,7 @@ def read_samples_b(filename, start, in_size, min_size=0):
scipy.int8, gr.sizeof_char)
# Bit of a hack since we want to read the data as signed ints, but
# the gr.vector_source_b will only accept unsigned. We read in as
# signed, do our min/max and things on that, then convert here.
d = scipy.array(d, dtype=scipy.uint8).tolist()
return d,mn,mx
@@ -122,7 +124,7 @@ class source_ints_to_float(gr.hier_block2):
gr.hier_block2.__init__(self, "ints_to_floats",
gr.io_signature(0, 0, 0),
gr.io_signature(1, 1, gr.sizeof_float))
- self.src = gr.vector_source_i(data)
+ self.src = blocks.vector_source_i(data)
self.cvt = blocks.int_to_float()
self.connect(self.src, self.cvt, self)
@@ -134,7 +136,7 @@ class source_shorts_to_float(gr.hier_block2):
gr.hier_block2.__init__(self, "shorts_to_floats",
gr.io_signature(0, 0, 0),
gr.io_signature(1, 1, gr.sizeof_float))
- self.src = gr.vector_source_s(data)
+ self.src = blocks.vector_source_s(data)
self.cvt = blocks.short_to_float()
self.connect(self.src, self.cvt, self)
@@ -146,7 +148,7 @@ class source_chars_to_float(gr.hier_block2):
gr.hier_block2.__init__(self, "chars_to_floats",
gr.io_signature(0, 0, 0),
gr.io_signature(1, 1, gr.sizeof_float))
- self.src = gr.vector_source_b(data)
+ self.src = blocks.vector_source_b(data)
self.cvt = blocks.char_to_float()
self.connect(self.src, self.cvt, self)
@@ -91,7 +93,7 @@ def read_samples_b(filename, start, in_size, min_size=0):
scipy.int8, gr.sizeof_char)
# Bit of a hack since we want to read the data as signed ints, but
- # the gr.vector_source_b will only accept unsigned. We read in as
+ # the blocks.vector_source_b will only accept unsigned. We read in as
# signed, do our min/max and things on that, then convert here.
d = scipy.array(d, dtype=scipy.uint8).tolist()